server_client_20141211_234315

### config1 : test_load_balance

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 3.50075411797 sec | 5.76669311523 sec

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0
latency | 0.9 | 0.51 | 0.32 | 0.5 | 0.55 | 0.59 | 0.73 | 0.87 | 0.14

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 36.38 | 29.27 | 25.53 | 25.91 | 31.15 | 34.28 | 35.33 | 36.17 | 5.02
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.503
server1-perf | latency | mean lt 0.33 | 0.508
server1-perf | qps | mean lt 7.0 | 4.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 25.914
client1-perf | latency | mean lt 35.0 | 29.2746666667
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None